| netplot-package | R Documentation |
netplot is a graph visualization engine that emphasizes aesthetics while
providing default parameters that yield out-of-the-box nice visualizations.
It is built on top of the grid graphics system (the same engine behind
ggplot2) and works seamlessly with igraph and network objects.
The main entry point is nplot(). See vignette("examples", package = "netplot") for a general overview and vignette("formulas", package = "netplot") for mapping vertex/edge aesthetics from graph attributes.
Maintainer: George Vega Yon g.vegayon@gmail.com (ORCID)
Authors:
George Vega Yon g.vegayon@gmail.com (ORCID)
Porter Bischoff portergbischoff@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.